# -*- coding: utf-8 -*-

DATA_SET = [
    (
        u"msgid",
        u"msgid"
    ),
    (
        u"msgid: %s",
        u"msgid: <span class=notranslate>%s</span>"
    ),
    (
        u"msgid: %d",
        u"msgid: <span class=notranslate>%d</span>"
    ),
    (
        u"msgid: %r",
        u"msgid: <span class=notranslate>%r</span>"
    ),
    (
        u"msgid: %(name)s",
        u"msgid: <span class=notranslate>%(name)s</span>"
    ),
    (
        u"msgid: %(name)d",
        u"msgid: <span class=notranslate>%(name)d</span>"
    ),
    (
        u"msgid: %(name)r",
        u"msgid: <span class=notranslate>%(name)r</span>"
    ),
    (
        u"msgid: '%s'",
        u"msgid: <span class=notranslate>'%s'</span>"
    ),
    (
        u"msgid: '%d'",
        u"msgid: <span class=notranslate>'%d'</span>"
    ),
    (
        u"msgid: '%r'",
        u"msgid: <span class=notranslate>'%r'</span>"
    ),
    (
        u'msgid: "%s"',
        u'msgid: <span class=notranslate>"%s"</span>'
    ),
    (
        u'msgid: "%d"',
        u'msgid: <span class=notranslate>"%d"</span>'
    ),
    (
        u'msgid: "%r"',
        u'msgid: <span class=notranslate>"%r"</span>'
    ),
]
